@@ -1077,12 +1077,12 @@ def make(*args,server,port,online):
                 r = 2*"    "
                 # javacode = javacode.replace('public void onEnable(){\n', 'public void onEnable(){\n'+r+'this.getCommand("'+code+'").setExecutor(this);\n')
                 file1 = open("data/src/main/resources/plugin.yml","r")
-                file = open("data/src/main/resources/plugin.yml","a")
+                filek = open("data/src/main/resources/plugin.yml","a")
                 if not file1.readlines().__contains__("commands:\n"):
                     file1.close()
-                    file.write('commands:\n')
-                file.write('  '+code+':\n')
-                file.close()
+                    filek.write('commands:\n')
+                filek.write('  '+code+':\n')
+                filek.close()
             elif m == "make":
                 del check_list[0]
                 if howmany ==1:
@@ -1119,9 +1119,10 @@ def make(*args,server,port,online):
     addition = ""
     for code1 in addition_list:
         addition += 'import '+code1 +';\n'
-    file = open("data/src/main/java/Main/Main.java","w")
+    files = open("data/src/main/java/Main/Main.java","w")
     last_String = 'package Main;\n\n'+addition+javacode
-    file.write(last_String)
+    files.write(last_String)
+    files.close()
     minepy = "python minepy.py"
     if server == True:
         minepy += " -s"
